package WebGUI::i18n::German::Asset_Carousel;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1301988649',
    'message' => 'Karussell'
  },
  'carousel autoPlay description' => {
    'lastUpdated' => '1301988620',
    'message' => 'Soll dieses Karussell automatisch durch die Einträge scrollen?'
  },
  'carousel autoPlay label' => {
    'lastUpdated' => '1301988661',
    'message' => 'Auto Play'
  },
  'carousel autoPlayInterval description' => {
    'lastUpdated' => '1301988714',
    'message' => 'Länge in Sekunden zwischen den Karussell-Wechseln'
  },
  'carousel autoPlayInterval label' => {
    'lastUpdated' => '1301988729',
    'message' => 'Auto-Play Intervall'
  },
  'carousel slideHeight description' => {
    'lastUpdated' => '1281649002',
    'message' => 'Höhe in Pixel. Das Carousel passt seine Größe nicht selbst automatisch bei unterschiedlichen Höhen an. Das Vorgeben dieser Höhe führt zu einer besseren Darstellung. Beim Standardwert \'0\' wird die Höhe des Carousels auf die Höhe des ersten Carousel-Elements gesetzt.'
  },
  'carousel slideHeight label' => {
    'lastUpdated' => '1279222341',
    'message' => 'Höhe des Carousel-Bereichs '
  },
  'carousel slideWidth description' => {
    'lastUpdated' => '1250973472',
    'message' => 'Breite in Pixel. Die Carouselbreite wird nicht automatische angepasst an den Inhalt. Die Einstellung der Breite unterstützt den Seitenaufbau. Wenn 0, wird die Breite durch die Breite des ersten Elements festgelegt.'
  },
  'carousel slideWidth label' => {
    'lastUpdated' => '1250973525',
    'message' => 'Carousel Frame/Seitenbreite'
  },
  'carousel template description' => {
    'lastUpdated' => '1244064150',
    'message' => 'Selektiere eine Vorlage zu diesem Carousel'
  },
  'carousel template help title' => {
    'lastUpdated' => '1244064195',
    'message' => 'Carousel Vorlage Variabele'
  },
  'carousel template label' => {
    'lastUpdated' => '1244064459',
    'message' => 'Carouselvorlage'
  },
  'delete' => {
    'lastUpdated' => '1295596758',
    'message' => 'Löschen'
  },
  'id description' => {
    'lastUpdated' => '1244064296',
    'message' => 'Geben Sie eine eindeutige ID für dieses Carouselitem ein.'
  },
  'id label' => {
    'lastUpdated' => '1244064257',
    'message' => 'ID'
  },
  'itemId' => {
    'lastUpdated' => '1244064324',
    'message' => 'Item-Id für dieses Carousel'
  },
  'item_loop' => {
    'lastUpdated' => '1244064403',
    'message' => 'Eine Schleife mit den Items dieses Carousels.'
  },
  'items description' => {
    'lastUpdated' => '1244064429',
    'message' => 'Geben Sie die Items zu diesem Carousel ein.'
  },
  'items label' => {
    'lastUpdated' => '1244064335',
    'message' => 'Items'
  },
  'rich editor description' => {
    'lastUpdated' => '1303289466',
    'message' => 'Wählen Sie einen Komfort-Editor für die Inhaltseingabe in die Carousel-Bereiche. Diese Einstellung wird bei der nächsten Carousel-Nutzung wirksam.'
  },
  'sequenceNumber' => {
    'lastUpdated' => '1244064369',
    'message' => 'Folgenummer für dieses Carouselitem.'
  },
  'slideHeight' => {
    'lastUpdated' => '1279222307',
    'message' => 'Die Höhe für jeden Bereich im Carousel.'
  },
  'slideWidth' => {
    'lastUpdated' => '1279222314',
    'message' => 'Die Breite für jeden Bereich im Carousel.'
  },
  'text' => {
    'lastUpdated' => '1244064238',
    'message' => 'Text zu diesem Carousel Item'
  }
}
;

1;
